using System;
using System.Runtime.InteropServices;

/// <summary>
/// RAI-12/RAI-16 API library definitions
/// </summary>
public class RAIxx
{
    //
    // Device status (Return codes)
    //
    public const int RAI_OK = 0;
    public const int RAI_INVALID_ID = 1;
    public const int RAI_DEVICE_NOT_FOUND = 2;
    public const int RAI_DEVICE_NOT_OPENED = 3;
    public const int RAI_OTHER_ERROR = 4;
    public const int RAI_COMMUNICATION_ERROR = 5;
    public const int RAI_INVALID_PARAMETER = 6;
    public const int RAI_MEMORY_ERROR = 7;

    //
    // Sampling Rate
    //
    public const int RAI_SAMPLING_RATE_10KSPS = 1;
    public const int RAI_SAMPLING_RATE_1KSPS = 10;
    public const int RAI_SAMPLING_RATE_100SPS = 100;
    public const int RAI_SAMPLING_RATE_10SPS = 1000;

    //
    // Trigger CH
    //
    public const byte RAI_TRIGGER_CH0 = 0x00;
    public const byte RAI_TRIGGER_CH1 = 0x01;
    public const byte RAI_TRIGGER_CH2 = 0x02;
    public const byte RAI_TRIGGER_CH3 = 0x03;

    //
    // Trigger Type
    //
    public const byte RAI_TRIGGER_TYPE_LEVEL_H = 0x00;
    public const byte RAI_TRIGGER_TYPE_LEVEL_L = 0x01;
    public const byte RAI_TRIGGER_TYPE_SLOPE_RISING = 0x02;
    public const byte RAI_TRIGGER_TYPE_SLOPE_FALLING = 0x03;


    //
    // Device Functions
    //
    [DllImport("RAIxx.dll")]
    public static extern int RAI_GetNumberOfDevices (out int Number);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_GetSerialNumber (int Index, out int SerialNumber);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_Open (out byte ID);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_OpenBySerialNumber (int SerialNumber, out byte ID);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_Close(byte ID);

    //
    // A/D Functions
    //
    [DllImport("RAIxx.dll")]
    public static extern int RAI_GetAnalogVoltage (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH0Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH1Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH2Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH3Value, int SamplingCount);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_GetAnalogVoltageEx (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH0Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH1Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH2Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH3Value, int SamplingRate, int SamplingCount);
    [DllImport("RAIxx.dll")]
    public static extern int RAI_GetAnalogVoltageExEx(byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH0Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH1Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH2Value, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object CH3Value, int SamplingRate, int SamplingCount, out int ReadCount, byte TriggerCH, byte TriggerType, double TriggerThreshold, int TriggerWaitCount);
}
